cd "/Users/bodet/Documents/Bodet UBC/POLI574/Data/"

use Party2.dta, clear   /*Progressive-Conservative Party of Canada*/

replace nationalchances=0 if nationalchances<.5
replace nationalchances=1 if nationalchances>=.5 & nationalchances~=.

*Level-1: Invidivual voters
*Level-2: Ridings AND/OR Day of campaign

sort day idnum   /* let's start with level2=riding and local chances */
xtset day idnum   /* though idnum is not a time variable! */
*
xtsum nationalchances /* some descriptive stats */

*************************
*p.246 - A simple logit?*
*************************

reg nationalchances idf soph atlant quebec prairie bc, rob   /* it has to be heteroskedastic */
logit nationalchances idf soph atlant quebec prairie bc
logit nationalchances idf soph atlant quebec prairie bc, or

/* If nationalchances=20% if idf=0, then nationalchances=49% (49/20~~2.43) */
/* If nationalchances=10% if soph=0, then nationalchances=25% if soph=1 (25/10~~2.51) */

********************************
*p.248 - Random-intercept model*
********************************

xtlogit nationalchances, i(day) quad(30)

xtmelogit nationalchances || day: , intpoints(30) variance /* why 30 intpoints? */

/* how do you calculate intra-class correlation? var(u)/(var(u)+(pi^2)/3) */
di .1217/(.1217+(3.1416^2)/3)

*
which gllamm /* if error message, type "ssc install gllamm, replace" */
gllamm nationalchances, i(day) link(logit) family(binom) nip(12) adapt


*****************************************
*Random-intercept models with covariates*
*****************************************

xtmelogit nationalchances idf soph atlant quebec prairie bc || day: , intpoints(30) variance or /* why 30 intpoints? */
*
gllamm nationalchances idf soph atlant quebec prairie bc, i(day) link(logit) family(binom) nip(12) adapt
gllamm, eform   /* odds ratio */
est store gllamm

******************************************
*Random-coefficient model with covariates*
******************************************

/* glamm is more versatile but quite computing intensive */
xtmelogit nationalchances idf soph atlant quebec prairie bc poll noise poll_noise || day: , intpoints(30) variance or /* why 30 intpoints? */
xtmelogit nationalchances idf soph atlant quebec prairie bc poll noise poll_noise || day: idf soph , intpoints(30) variance or /* why 30 intpoints? */

gllamm nationalchances idf soph atlant quebec prairie bc poll noise poll_noise, i(day) link(logit) family(binom) nip(12) adapt
*ouch!*

*******************
*p.158 - Adaptive!*
*******************

gllamm nationalchances soph, i(day) link(logit) family(binom) nip(12) adapt   /* For a simple model! */

eq slope: soph
gen cons = 1
eq inter: cons
matrix a = e(b)
matrix a = (a, 0, 0)

gllamm nationalchances soph, i(day) nrf(2) eqs(inter slope) ip(m) nip(15)   /* trust Stata! */
gllamm nationalchances soph, i(day) nrf(2) eqs(inter slope) ip(m) nip(15) adapt from(a) skip /*might or might not help */
